@@ -6,16 +6,23 @@ from .. import DataStreamProcessor, schema_validator
 
 class set_type(DataStreamProcessor):
 
-    def __init__(self, name, resources=-1, **options):
+    def __init__(self, name, resources=-1, on_error=None, **options):
         super(set_type, self).__init__()
         self.name = re.compile(f'^{name}$')
         self.options = options
         self.resources = resources
+        self.field_names = []
+        self.on_error = on_error
 
     def process_resources(self, resources):
         for res in resources:
             if self.matcher.match(res.res.name):
-                yield schema_validator(res.res, res)
+                if len(self.field_names) > 0:
+                    yield schema_validator(res.res, res,
+                                           field_names=self.field_names,
+                                           on_error=self.on_error)
+                else:
+                    yield res
             else:
                 yield res
 
@@ -28,6 +35,7 @@ class set_type(DataStreamProcessor):
                 for field in res['schema']['fields']:
                     if self.name.match(field['name']):
                         field.update(self.options)
+                        self.field_names.append(field['name'])
                         added = True
         assert added, 'Failed to find field {} in schema'.format(self.name)
         return dp
